import { GitExecutor } from '../git-executor';
import { Options, outputHandler, SimpleGitTaskCallback } from '../types';
export declare type SimpleGitTaskTrailingCallback<R> = [SimpleGitTaskCallback<R>] | [];
export declare type SimpleGitTaskTrailingOptions<R, OPT = Options> = [OPT, SimpleGitTaskCallback<R>] | [string[], SimpleGitTaskCallback<R>] | [OPT] | [string[]] | SimpleGitTaskTrailingCallback<R>;
export declare class TaskBuilder {
    private _executor;
    private _promise;
    constructor(_executor: GitExecutor);
    /**
     * Sets the path to a custom git binary, should either be `git` when there is an installation of git available on
     * the system path, or a fully qualified path to the executable.
     */
    customBinary(command: string): this;
    /**
     * * Sets an environment variable for the spawned child process, either supply both a name and value as strings or
     * a single object to entirely replace the current environment variables.
     */
    env(name: string, value: string): this;
    /**
     * Sets the working directory of the subsequent commands.
     */
    cwd(workingDirectory: string, ...opt: SimpleGitTaskTrailingCallback<string>): this;
    addRemote(remoteName: string, remoteRepo: string, ...opt: SimpleGitTaskTrailingOptions<string>): this;
    outputHandler(handler: outputHandler): this;
    private _runTask;
}
