"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const task_1 = require("../tasks/task");
const utils_1 = require("../utils");
const task_callback_1 = require("../task-callback");
const remote_1 = require("../tasks/remote");
const git_error_1 = require("../errors/git-error");
class TaskBuilder {
    constructor(_executor) {
        this._executor = _executor;
        this._promise = Promise.resolve();
    }
    /**
     * Sets the path to a custom git binary, should either be `git` when there is an installation of git available on
     * the system path, or a fully qualified path to the executable.
     */
    customBinary(command) {
        this._executor.binary = command;
        return this;
    }
    env(...env) {
        if (env.length == 1) {
            this._executor.env = typeof env[0] === 'object' && env[0] || undefined;
        }
        else if (env.length === 2) {
            (this._executor.env = this._executor.env || {})[env[0]] = env[1];
        }
        return this;
    }
    /**
     * Sets the working directory of the subsequent commands.
     */
    cwd(workingDirectory, ...opt) {
        return this._runTask(task_1.execTask(() => {
            if (!utils_1.folderExists(workingDirectory)) {
                throw new git_error_1.GitError(undefined, `Git.cwd: cannot change to non-directory "${workingDirectory}"`);
            }
            return this._executor.cwd = workingDirectory;
        }), utils_1.trailingFunctionArgument(opt));
    }
    addRemote(remoteName, remoteRepo, ...opt) {
        return this._runTask(remote_1.addRemoteTask(remoteName, remoteRepo, utils_1.getTrailingOptions(opt)), utils_1.trailingFunctionArgument(opt));
    }
    outputHandler(handler) {
        this._executor.outputHandler = handler;
        return this;
    }
    _runTask(task, callback = utils_1.NOOP) {
        this._promise = this._executor.push(task);
        if (utils_1.isUserFunction(callback)) {
            task_callback_1.taskCallback(task, this._promise, callback);
        }
        return this;
    }
}
exports.TaskBuilder = TaskBuilder;
//# sourceMappingURL=task-builder.js.map